@@ -129,9 +129,14 @@ update_default_input (GvcMixerDialog *dialog)
 {
         GtkTreeModel *model;
         GtkTreeIter   iter;
+        gboolean      ret;
 
         model = gtk_tree_view_get_model (GTK_TREE_VIEW (dialog->priv->input_treeview));
-        gtk_tree_model_get_iter_first (model, &iter);
+        ret = gtk_tree_model_get_iter_first (model, &iter);
+        if (ret == FALSE) {
+                g_debug ("No default input selected or available");
+                return;
+        }
         do {
                 gboolean        toggled;
                 gboolean        is_default;
@@ -369,8 +374,11 @@ on_mixer_control_default_sink_changed (GvcMixerControl *control,
 
         g_debug ("GvcMixerDialog: default sink changed: %u", id);
 
-        stream = gvc_mixer_control_lookup_stream_id (dialog->priv->mixer_control,
-                                                     id);
+        if (id == PA_INVALID_INDEX)
+                stream = NULL;
+        else
+                stream = gvc_mixer_control_lookup_stream_id (dialog->priv->mixer_control,
+                                                             id);
         bar_set_stream (dialog, dialog->priv->output_bar, stream);
 
         update_output_settings (dialog);
@@ -528,9 +536,40 @@ create_monitor_stream_for_source (GvcMixerDialog *dialog,
                 pa_stream_unref (s);
         } else {
                 g_object_set_data (G_OBJECT (stream), "has-monitor", GINT_TO_POINTER (TRUE));
+                g_object_set_data (G_OBJECT (dialog->priv->input_level_bar), "pa_stream", s);
+                g_object_set_data (G_OBJECT (dialog->priv->input_level_bar), "stream", stream);
         }
 }
 
+static void
+stop_monitor_stream_for_source (GvcMixerDialog *dialog)
+{
+        pa_stream      *s;
+        pa_context     *context;
+        int             res;
+        GvcMixerStream *stream;
+
+        s = g_object_get_data (G_OBJECT (dialog->priv->input_level_bar), "pa_stream");
+        if (s == NULL)
+                return;
+        stream = g_object_get_data (G_OBJECT (dialog->priv->input_level_bar), "stream");
+        g_assert (stream != NULL);
+
+        g_debug ("Stopping monitor for %u", pa_stream_get_index (s));
+
+        context = gvc_mixer_control_get_pa_context (dialog->priv->mixer_control);
+
+        if (pa_context_get_server_protocol_version (context) < 13) {
+                return;
+        }
+
+        res = pa_stream_disconnect (s);
+        if (res == 0)
+                g_object_set_data (G_OBJECT (stream), "has-monitor", GINT_TO_POINTER (FALSE));
+        g_object_set_data (G_OBJECT (dialog->priv->input_level_bar), "pa_stream", NULL);
+        g_object_set_data (G_OBJECT (dialog->priv->input_level_bar), "stream", NULL);
+}
+
 static void
 update_input_settings (GvcMixerDialog *dialog)
 {
@@ -539,6 +578,8 @@ update_input_settings (GvcMixerDialog *dialog)
 
         g_debug ("Updating input settings");
 
+        stop_monitor_stream_for_source (dialog);
+
         if (dialog->priv->input_port_combo != NULL) {
                 gtk_container_remove (GTK_CONTAINER (dialog->priv->input_settings_box),
                                       dialog->priv->input_port_combo);
@@ -547,7 +588,7 @@ update_input_settings (GvcMixerDialog *dialog)
 
         stream = gvc_mixer_control_get_default_source (dialog->priv->mixer_control);
         if (stream == NULL) {
-                g_warning ("Default source stream not found");
+                g_debug ("Default source stream not found");
                 return;
         }
 
@@ -589,7 +630,10 @@ on_mixer_control_default_source_changed (GvcMixerControl *control,
 
         g_debug ("GvcMixerDialog: default source changed: %u", id);
 
-        stream = gvc_mixer_control_lookup_stream_id (dialog->priv->mixer_control, id);
+        if (id == PA_INVALID_INDEX)
+                stream = NULL;
+        else
+                stream = gvc_mixer_control_lookup_stream_id (dialog->priv->mixer_control, id);
 
         /* Disconnect the adj, otherwise it might change if is_amplified changes */
         adj = GTK_ADJUSTMENT (gvc_channel_bar_get_adjustment (GVC_CHANNEL_BAR (dialog->priv->input_bar)));
