@@ -23,13 +23,13 @@
 #define GM_AUDIO_PROFILE_CHOOSE_H
 
 #include "audio-profile.h"
-#include <gtk/gtkcombobox.h>
+#include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
 
 G_BEGIN_DECLS
 
 /* create a new Profile Choose Dialog */
-GtkWidget*      gm_audio_profile_choose_new		();
+GtkWidget*      gm_audio_profile_choose_new		(void);
 GMAudioProfile* gm_audio_profile_choose_get_active	(GtkWidget  *choose);
 gboolean        gm_audio_profile_choose_set_active	(GtkWidget  *choose,
 							 const char *id);
